#
# spec file for package thai-fonts
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           thai-fonts
Version:        0.7.3
Release:        1.12
Summary:        A Collection of Thai OpenType Fonts
License:        GPL-2.0-only WITH Font-exception-2.0 AND LPPL-1.3c
Group:          System/X11/Fonts
URL:            https://linux.thai.net/projects/fonts-tlwg
Source0:        https://linux.thai.net/pub/thailinux/software/fonts-tlwg/fonts-tlwg-%{version}.tar.xz
BuildRequires:  fontpackages-devel
Patch0:         build.patch
BuildRequires:  fontconfig
BuildRequires:  fontforge >= 20190801
BuildRequires:  xz
%reconfigure_fonts_prereq
Provides:       locale(th)
Obsoletes:      fonts-thai < 0.4.16
Provides:       fonts-thai = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Fonts-TLWG is a collection of Thai scalable fonts. It provides
fonts that conform to existing standards and recommendations, so that it
can be a reference implementation.

The fonts included are Garuda, Kinnari, Laksaman, Loma, Norasi, Purisa,
Sawasdee, TlwgMono, TlwgTypewriter, TlwgTypo, Umpush and Waree.

%prep
%autosetup -n fonts-tlwg-%{version} -p1

%build
%configure --with-ttfdir=%{_ttfontsdir}
%make_build

%install
%make_install
rm -f %{buildroot}%{_ttfontsdir}/encodings.dir
rm -f %{buildroot}%{_ttfontsdir}/fonts.*
mkdir -p %{buildroot}%{_fontsconfavaildir}
mv %{buildroot}%{_datadir}/fontconfig/conf.avail/*.conf %{buildroot}%{_fontsconfavaildir}

%reconfigure_fonts_scriptlets

%files
%doc AUTHORS COPYING NEWS README ChangeLog
%files_fontsconf_availdir
%{_fontsdir}/opentype/
%files_fontsconf_availdir
%files_fontsconf_file 64-01-tlwg-kinnari.conf
%files_fontsconf_file 64-02-tlwg-norasi.conf
%files_fontsconf_file 64-10-tlwg-loma.conf
%files_fontsconf_file 64-11-tlwg-waree.conf
%files_fontsconf_file 64-13-tlwg-garuda.conf
%files_fontsconf_file 64-14-tlwg-umpush.conf
%files_fontsconf_file 64-15-laksaman.conf
%files_fontsconf_file 64-21-tlwg-typo.conf
%files_fontsconf_file 64-22-tlwg-typist.conf
%files_fontsconf_file 64-23-tlwg-mono.conf
%files_fontsconf_file 89-tlwg-garuda-synthetic.conf
%files_fontsconf_file 89-tlwg-kinnari-synthetic.conf
%files_fontsconf_file 89-tlwg-umpush-synthetic.conf
%files_fontsconf_file 89-tlwg-laksaman-synthetic.conf

%changelog
* Mon Oct 18 2021 andy great <andythe_great@pm.me>
- Update to version 0.7.3.
  * Purisa, Sawasdee: now can be embeded as installable in PDF.
  * TlwgTypo, TlwgTypist: fix uneven widths of some glyphs.
  * TlwgTypo, TlwgTypist, TlwgMono, TlwgTypewriter: clear PANOSE to use
    calculated values, so as to get listed in gvim.
  * Norasi: add 'onum' and 'smcp' OpenType features for access to
    old style figures and small caps glyphs.
  * LaTeX: Add old style figures and small caps supports for Norasi.
* Fri Feb  5 2021 Jan Engelhardt <jengelh@inai.de>
- Utilize modern rpm macros. Nudge the description a bit.
* Thu Feb  4 2021 andy great <andythe_great@pm.me>
- Update description.
* Thu Aug 13 2020 andy great <andythe_great@pm.me>
- Update to version 0.7.2.
  * Garuda has been fine-tuned by hand for balanced cubic splines
    and optimal quadratic splines.
  * All families now use OS/2 Typo metrics instead of just Win/Hhea
    metrics.
  * The OS/2 Typo metrics of each family have been normalized for
    equal line spacing on all faces, esp. regular and bold.
  * Switch to Python 3 on build scripts.
  * Fix a TDS zipball naming issue in the generated CTAN zipball.
* Mon Feb 19 2018 coolo@suse.com
- make the license SPDX compliant
* Tue Nov 18 2014 pgajdos@suse.com
- updated to 0.6.1:
  * New font: Laksaman (Sarabun derivative).
  * Split fontconfig files to allow individual fonts installation.
  * LaTeX options for setting default fonts.
* Mon Mar 31 2014 pgajdos@suse.com
- updated to 0.6.0:
  * Supports more combinations of vertical mark stacking, for ethnic languages.
  * Umpush Light can now be used with LaTeX.
  * Spline clean-ups in several fonts.
* Tue Jan 21 2014 pgajdos@suse.com
- build require xz (for SLE_11_SP{2,3})
* Tue Jan 21 2014 pgajdos@suse.com
- updated to 0.5.1, project renamed to fonts-tlwg:
  * Add missing glyphs for LaTeX in monospace fonts.
  * Fix malformed fontconfig config.
  * Add glyphs for Esperanto to Purisa.
  * More consistent directory names for LaTeX installation.
  * More Latin glyphs in all fonts.
  * Fine-tuned Latin glyphs for Loma and Umpush.
  * Corrected GSUB rules for Pali-Sanskrit descender removal in
    all fonts.
  * Miscellaneous bug fixes in fonts.
* Mon Oct  8 2012 pgajdos@suse.com
- use %%files_fontsconf_availdir and %%files_fontsconf_file macros
* Tue Oct  2 2012 pgajdos@suse.com
- moved /etc/fonts/conf.avail/*.conf to /usr/share/%%{name}/conf.avail/
  as /etc/fonts/conf.avail is obsoleted with fontconfig 2.10
* Wed Jul  4 2012 pgajdos@suse.cz
- amend spec file to reflect new font packaging scheme
  (see openFATE#313536);
* Thu May 17 2012 pgajdos@suse.com
- call spec-cleaner
* Wed Mar 14 2012 cfarrell@suse.com
- license update: GPL-2.0-with-font-exception and LPPL-1.3c
  This package is not public domain. Also, use SPDX format
* Wed Feb  1 2012 pgajdos@suse.com
- updated to 0.4.17:
  * Build-depends on ThaiLaTeX and uses the shared resource from there
  * Supports automated distributed ZIP preparation for CTAN upload.
  * Other cleanups.
* Wed Feb  1 2012 pgajdos@suse.com
- renamed to thai-fonts
* Mon Oct 31 2011 pgajdos@suse.com
- updated to 0.4.16:
  - Fix GSUB rules to correctly remove YO YING descender when combined with
    both lower and upper characters
  - Clear improper fraction rules in monospace fonts.
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Mon May 23 2011 pgajdos@novell.com
- updated to 0.4.15 (see NEWS)
* Mon Aug 30 2010 pgajdos@suse.cz
- updated to 0.4.14 (see NEWS)
* Thu Apr  8 2010 tiwai@suse.de
- removed unnecessary buidlrequires
- minor clean-up of filelist
* Mon Dec  7 2009 pgajdos@suse.cz
- updated to 0.4.13 (see NEWS)
- some spec file cleanups
* Fri Aug  4 2006 mfabian@suse.de
- move fonts to /usr/share/fonts/ in STABLE (paths changed
  because of the move to Xorg X11R7).
* Wed Mar  1 2006 mfabian@suse.de
- add "Provides: locale(th)".
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep 15 2005 uli@suse.de
- update -> 0.4.3.1, build from source (DBThaiText* dropped due
  to licensing issues, new fonts Loma, TlwgMono, TlwgTypewriter)
* Fri Dec  3 2004 mfabian@suse.de
- use new macro "%%run_suseconfig_fonts".
* Thu Mar 18 2004 mfabian@suse.de
- use %%suseconfig_fonts_prereq
* Sat Feb 14 2004 mfabian@suse.de
- don't build as root
- run SuSEconfig.fonts and SuSEconfig.pango in %%post and %%postun
* Fri Jun 13 2003 mfabian@suse.de
- add %%dir /usr/X11R6/lib/X11/fonts/truetype/ to file list.
* Tue May 27 2003 mfabian@suse.de
- new package: fonts-thai version 0.cvs.20030527
